# Harissa notebooks

* **Notebook 1 - Simulation**  
Simulate a basic repressilator network with 3 genes

* **Notebook 2 - Inference**  
Perform network inference from a small dataset with 4 genes

* **Notebook 3 - Identifiability**  
Compare two different branching pathways with 4 genes, from both ‘single-cell’ and ‘bulk’ viewpoints
